Module blaxel.core.client.models.job_execution_config
=====================================================

Classes
-------

`JobExecutionConfig(max_concurrent_tasks: blaxel.core.client.types.Unset | int = <blaxel.core.client.types.Unset object>, max_retries: blaxel.core.client.types.Unset | int = <blaxel.core.client.types.Unset object>, timeout: blaxel.core.client.types.Unset | int = <blaxel.core.client.types.Unset object>)`
:   Configuration for a job execution
    
    Attributes:
        max_concurrent_tasks (Union[Unset, int]): The maximum number of concurrent tasks for an execution
        max_retries (Union[Unset, int]): The maximum number of retries for the job execution
        timeout (Union[Unset, int]): The timeout for the job execution in seconds
    
    Method generated by attrs for class JobExecutionConfig.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `max_concurrent_tasks: blaxel.core.client.types.Unset | int`
    :

    `max_retries: blaxel.core.client.types.Unset | int`
    :

    `timeout: blaxel.core.client.types.Unset | int`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :